@@ -2,6 +2,7 @@
 
 from ._class2 import *
 from . import _plot_as_array
+from . import _plot_as_profile1d
 from . import _plot_correlations
 from . import _plot_BvsA_as_distribution
 
@@ -73,6 +74,64 @@ class DataStock3(DataStock2):
             inplace=inplace,
         )
 
+    def plot_as_profile1d(
+        self,
+        # parameters
+        key=None,
+        key_time=None,
+        keyX=None,
+        ind=None,
+        vmin=None,
+        vmax=None,
+        cmap=None,
+        aspect=None,
+        nmax=None,
+        color_dict=None,
+        dinc=None,
+        lkeys=None,
+        bstr_dict=None,
+        rotation=None,
+        inverty=None,
+        bck=None,
+        # figure-specific
+        dax=None,
+        dmargin=None,
+        fs=None,
+        dcolorbar=None,
+        dleg=None,
+        connect=None,
+        inplace=None,
+    ):
+        """ Plot the desired 2d data array as a time-varying 1d profile """
+        return _plot_as_profile1d.plot_as_profile1d(
+            # parameters
+            coll=self,
+            key=key,
+            key_time=key_time,
+            keyX=keyX,
+            ind=ind,
+            vmin=vmin,
+            vmax=vmax,
+            cmap=cmap,
+            aspect=aspect,
+            nmax=nmax,
+            color_dict=color_dict,
+            dinc=dinc,
+            lkeys=lkeys,
+            bstr_dict=bstr_dict,
+            rotation=rotation,
+            inverty=inverty,
+            bck=bck,
+            # figure-specific
+            dax=dax,
+            dmargin=dmargin,
+            fs=fs,
+            dcolorbar=dcolorbar,
+            dleg=dleg,
+            connect=connect,
+            inplace=inplace,
+        )
+
     def plot_correlations(
         self,
         # correlations
